@@ -551,7 +551,7 @@ class TradefedLogsPluginTest(unittest.TestCase):
         type(content_mock).read = lambda s: 'abc'
         type(extracted_file_mock).contents = content_mock
         self.plugin._create_testrun_attachment(testrun_mock, name, extracted_file_mock, "text/plain")
-        testrun_mock.attachments.create.assert_called_with(old_data='abc', filename='name', length=2, mimetype='text/plain')
+        testrun_mock.attachments.create.assert_called_with(filename='name', length=2, mimetype='text/plain')
 
     @patch("tradefed.Tradefed._download_results")
     def test_get_from_artifactorial(self, download_results_mock):
